# Apple Wallet Integration Guide

This document provides instructions for setting up and troubleshooting Apple Wallet integration for loyalty cards.

## Overview

The system provides two approaches for adding loyalty cards to Apple Wallet:

1. **Direct PKPass Generation**: Creates a `.pkpass` file that users can download and add to their Apple Wallet.
2. **Screenshot/Share Method**: Provides instructions for users to take a screenshot and add it to their wallet.

The direct PKPass generation method requires valid Apple Developer certificates and may not work in all environments. The screenshot method is a fallback that works in all cases.

## Files and Components

- `apple_wallet_instructions.php`: Provides user-friendly instructions for adding cards to Apple Wallet.
- `test_certificates_live.php`: Tests if your server can handle Apple Wallet certificates.
- `simple_pkpass_test.php`: Creates a simple test PKPass file using PEM certificates.
- `download_test_pass.php`: Handles downloading the test PKPass file.

## Certificate Requirements

To generate valid PKPass files, you need:

1. **Apple Developer Account**: Enroll in the Apple Developer Program.
2. **Pass Type ID**: Create a Pass Type ID in your Apple Developer account.
3. **Certificates**:
   - Pass Type ID Certificate (`.p12` file)
   - Apple Worldwide Developer Relations Certificate (WWDR)
   - Password for the `.p12` certificate file

## Server Requirements

The server must have:
- PHP 7.0+ with OpenSSL, ZIP, JSON, and GD extensions enabled
- OpenSSL with support for modern encryption algorithms
- HTTPS for production use (Apple requires this)

## Testing Your Environment

1. **Test Certificate Handling**: 
   ```
   https://yourdomain.com/customer/test_certificates_live.php
   ```
   This will check if your environment can properly handle the certificates.

2. **Test PKPass Generation**:
   ```
   https://yourdomain.com/customer/simple_pkpass_test.php
   ```
   This will attempt to generate a simple PKPass file.

## Troubleshooting

### Common Issues

1. **OpenSSL Errors**:
   - "unsupported algorithm": Your OpenSSL version doesn't support the algorithm used in the certificate.
   - Solution: Update OpenSSL or export certificates with different encryption.

2. **Certificate Password Issues**:
   - "MAC verification failed": Incorrect password for the certificate.
   - Solution: Double-check the password or re-export the certificate.

3. **Invalid Certificate Format**:
   - "error:0906D06C:PEM routines": Certificate format issues.
   - Solution: Make sure you're using the correct certificate files and formats.

4. **Missing Extensions**:
   - "Call to undefined function...": PHP extension is missing.
   - Solution: Install the required PHP extensions.

### Alternative Approaches

If direct PKPass generation doesn't work on your server:

1. **Use the screenshot method** as outlined in `apple_wallet_instructions.php`.
2. **Use third-party services** that can generate PKPass files, such as PassKit or Wallet Passes.
3. **Generate PKPass files offline** using a tool like Pass Designer and serve them through your website.

## Updating to Production

When moving to production:

1. **Update pass.json fields**:
   - `passTypeIdentifier`: Should match your registered Pass Type ID (e.g., "pass.com.yourcompany.loyaltycard")
   - `teamIdentifier`: Your Apple Developer Team ID
   - `webServiceURL`: Your actual pass web service URL (if implementing pass updates)

2. **Replace test certificates** with your actual production certificates.

3. **Ensure HTTPS** is enabled on your production server.

## Support

For more information, refer to:
- [Apple PassKit Documentation](https://developer.apple.com/documentation/walletpasses)
- [Apple Wallet Guidelines](https://developer.apple.com/design/human-interface-guidelines/wallet) 