<?php
require_once '../includes/functions.php';
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Development Mode for Apple Wallet Integration</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="max-w-3xl mx-auto bg-white rounded-lg shadow-md overflow-hidden">
        <div class="bg-blue-600 text-white p-4">
            <h1 class="text-2xl font-bold">Development Mode for Apple Wallet Integration</h1>
            <p class="mt-1">Testing PKPass generation without certificate validation</p>
        </div>
        
        <div class="p-6">
            <div class="flex items-center justify-center mb-6 bg-yellow-50 p-4 rounded-lg border border-yellow-200">
                <div class="flex-shrink-0 text-yellow-500 mr-3">
                    <svg class="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z" />
                    </svg>
                </div>
                <p class="text-yellow-700">
                    <strong>Development Mode Only:</strong> The PKPass files generated in development mode are technically invalid but may be useful for testing purposes. They will not work in production environments.
                </p>
            </div>
            
            <h2 class="text-xl font-bold text-gray-700 mb-4">Why Development Mode?</h2>
            <p class="mb-4">
                Apple Wallet passes (.pkpass files) typically require proper certificate signing to work correctly. 
                However, in local development environments like XAMPP, there can be issues with OpenSSL and certificate handling.
                Development mode bypasses these requirements to allow testing of the pass structure and appearance.
            </p>
            
            <h2 class="text-xl font-bold text-gray-700 mb-4">How It Works</h2>
            <p class="mb-4">
                Development mode creates a PKPass file with:
            </p>
            <ul class="list-disc pl-6 mb-6 space-y-2">
                <li>All the correct JSON structure and pass content</li>
                <li>Required images and resources</li>
                <li>A dummy signature file that makes the .pkpass format technically valid</li>
            </ul>
            
            <h2 class="text-xl font-bold text-gray-700 mb-4">Testing Development PKPass Files</h2>
            <p class="mb-4">
                You can test development PKPass files by:
            </p>
            <ol class="list-decimal pl-6 mb-6 space-y-3">
                <li>
                    <strong>Using the Test Card:</strong> Visit the
                    <a href="card.php?card_number=LC202503253423" class="text-blue-600 underline">test card page</a>
                    and click the "Add to Apple Wallet (Dev Mode)" button.
                </li>
                <li>
                    <strong>Via Email:</strong> Send the .pkpass file via email and open it on an iOS device.
                    <br>
                    <span class="text-sm text-gray-600">Note: While proper signed passes will open automatically, development passes may show as just attachments.</span>
                </li>
                <li>
                    <strong>Via File Transfer:</strong> Transfer the .pkpass file to an iOS device via AirDrop or file sharing.
                </li>
            </ol>
            
            <div class="bg-blue-50 border border-blue-200 rounded-lg p-4 mb-6">
                <h3 class="font-bold text-blue-800 mb-2">For Production Environments</h3>
                <p class="text-blue-700">
                    When deploying to a production environment with proper SSL support, switch to using the regular PKPass generator:
                </p>
                <pre class="bg-gray-100 p-3 rounded mt-2 text-sm overflow-x-auto">$pass = new PKPass($certificatePath, $certificatePassword, $wwdrCertPath);</pre>
                <p class="text-blue-700 mt-2">
                    The regular generator will create properly signed passes that work with Apple Wallet.
                </p>
            </div>
            
            <h2 class="text-xl font-bold text-gray-700 mb-4">Test a Development Pass</h2>
            <?php
            // Get a sample card for testing
            $conn = getDbConnection();
            $stmt = $conn->prepare("
                SELECT lc.*, c.name, c.email, l.name as location_name
                FROM loyalty_cards lc
                JOIN customers c ON lc.customer_id = c.id
                JOIN locations l ON c.location_id = l.id
                LIMIT 1
            ");
            $stmt->execute();
            $card = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($card) {
                echo '<div class="mt-4">';
                echo '<a href="generate_dev_pkpass.php?card_number=' . htmlspecialchars($card['card_number']) . '" class="inline-block px-6 py-3 bg-green-600 text-white font-medium rounded hover:bg-green-700 transition-colors">';
                echo 'Generate Test Pass for ' . htmlspecialchars($card['name']);
                echo '</a>';
                echo '</div>';
            }
            ?>
            
            <div class="mt-6 border-t pt-6">
                <a href="test_wallet.php" class="px-4 py-2 bg-blue-600 text-white rounded-lg hover:bg-blue-700 inline-block">
                    Back to Wallet Test Page
                </a>
            </div>
        </div>
    </div>
    
    <div class="max-w-3xl mx-auto mt-6 text-center text-sm text-gray-500">
        <p>Development Mode is intended only for testing purposes during local development.</p>
    </div>
</body>
</html> 