<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once '../vendor/autoload.php';
use PKPass\PKPass;

function debug($msg) {
    error_log("[Test Pass] " . $msg);
    echo $msg . "\n";
}

try {
    // Create minimal pass data
    $data = [
        'formatVersion' => 1,
        'passTypeIdentifier' => 'pass.com.trimscloud.loyalty',
        'serialNumber' => 'test123',
        'teamIdentifier' => 'C7CH6P3GLR',
        'organizationName' => 'Test Organization',
        'description' => 'Test Pass',
        'storeCard' => [
            'primaryFields' => [[
                'key' => 'test',
                'label' => 'TEST',
                'value' => 'Test Value'
            ]]
        ]
    ];

    // Initialize pass with absolute paths
    $certDir = __DIR__ . '/../certs/';
    $pass = new PKPass(
        realpath($certDir . 'signerCert.pem'),
        [realpath($certDir . 'signerKey.pem'), 'test'],
        realpath($certDir . 'Apple Worldwide Developer Relations Certification Authority.pem')
    );

    // Set pass data first
    $pass->setData($data);
    debug("Set pass data");

    // Add required images directly to the pass
    $images = [
        'icon.png' => true,
        'icon@2x.png' => true,
        'logo.png' => true,
        'logo@2x.png' => true
    ];

    foreach ($images as $image => $required) {
        $source = __DIR__ . '/../assets/images/wallet_images/' . $image;
        
        if (!file_exists($source)) {
            if ($required) {
                throw new Exception("Required image not found: " . $image);
            }
            continue;
        }
        
        $imageData = file_get_contents($source);
        if ($imageData === false) {
            throw new Exception("Failed to read " . $image);
        }
        
        if (!$pass->addFile($image, $imageData)) {
            throw new Exception("Failed to add " . $image . " to pass");
        }
        debug("Added " . $image . " (" . strlen($imageData) . " bytes)");
    }

    // Create temporary directory for pass creation
    $tempDir = sys_get_temp_dir() . '/pass_' . uniqid();
    mkdir($tempDir, 0755, true);
    debug("Created temporary directory: " . $tempDir);

    // Set temporary directory for pass creation
    $pass->setTempPath($tempDir);
    debug("Set temporary path: " . $tempDir);

    // Create pass file
    debug("Creating pass...");
    $passFile = $pass->create(false); // Don't output directly
    
    if (!$passFile) {
        throw new Exception("Failed to create pass");
    }
    debug("Pass created successfully");

    // Output pass file
    header('Content-Type: application/vnd.apple.pkpass');
    header('Content-Disposition: attachment; filename="test.pkpass"');
    header('Content-Length: ' . strlen($passFile));
    echo $passFile;

    // Cleanup
    if (is_dir($tempDir)) {
        array_map('unlink', glob($tempDir . '/*'));
        rmdir($tempDir);
    }

} catch (Exception $e) {
    debug("Error: " . $e->getMessage());
    debug("Stack trace: " . $e->getTraceAsString());
    
    // Cleanup on error
    if (isset($tempDir) && is_dir($tempDir)) {
        array_map('unlink', glob($tempDir . '/*'));
        rmdir($tempDir);
    }
} 