<?php
require_once __DIR__ . '/../includes/functions.php';

// Get a sample card for testing
$conn = getDbConnection();
$stmt = $conn->prepare("
    SELECT lc.*, c.name, c.email, l.name as location_name
    FROM loyalty_cards lc
    JOIN customers c ON lc.customer_id = c.id
    JOIN locations l ON c.location_id = l.id
    LIMIT 1
");
$stmt->execute();
$card = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$card) {
    die("No loyalty cards found in the system. Please create a card first.");
}

// Ensure pass images are generated
generateDefaultPassImages();
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Apple Wallet Test</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="max-w-lg mx-auto bg-white rounded-lg shadow-md p-6">
        <h1 class="text-2xl font-bold mb-4">Apple Wallet Integration Test</h1>
        
        <div class="mb-4">
            <p class="mb-2"><strong>Card Details:</strong></p>
            <ul class="pl-5 list-disc">
                <li><strong>Card Number:</strong> <?php echo htmlspecialchars($card['card_number']); ?></li>
                <li><strong>Customer:</strong> <?php echo htmlspecialchars($card['name']); ?></li>
                <li><strong>Location:</strong> <?php echo htmlspecialchars($card['location_name']); ?></li>
                <li><strong>Stamps:</strong> <?php echo htmlspecialchars($card['stamp_count']); ?></li>
            </ul>
        </div>
        
        <div class="mb-6">
            <p class="font-semibold mb-2">Setup status:</p>
            <ul class="pl-5 list-disc">
                <?php
                // Check for images
                $passImagesDir = __DIR__ . '/../assets/pass_images';
                $requiredImages = ['icon.png', 'icon@2x.png', 'logo.png', 'logo@2x.png', 'strip.png', 'strip@2x.png'];
                $allImagesExist = true;
                
                foreach ($requiredImages as $image) {
                    $exists = file_exists($passImagesDir . '/' . $image);
                    echo "<li class='" . ($exists ? 'text-green-600' : 'text-red-600') . "'>";
                    echo $image . ": " . ($exists ? 'Found' : 'Missing');
                    echo "</li>";
                    
                    if (!$exists) {
                        $allImagesExist = false;
                    }
                }
                
                // Check for certificates
                $certPath = __DIR__ . '/../certs/Certificates.p12';
                $wwdrPath = __DIR__ . '/../certs/AppleWWDRMPCA1G1.cer';
                
                $certExists = file_exists($certPath);
                $wwdrExists = file_exists($wwdrPath);
                
                echo "<li class='" . ($certExists ? 'text-green-600' : 'text-red-600') . "'>";
                echo "Certificates.p12: " . ($certExists ? 'Found' : 'Missing');
                echo "</li>";
                
                echo "<li class='" . ($wwdrExists ? 'text-green-600' : 'text-red-600') . "'>";
                echo "AppleWWDRMPCA1G1.cer: " . ($wwdrExists ? 'Found' : 'Missing');
                echo "</li>";
                ?>
            </ul>
        </div>
        
        <div class="flex justify-between">
            <a href="card.php?card_number=<?php echo urlencode($card['card_number']); ?>" 
               class="bg-blue-600 text-white px-4 py-2 rounded hover:bg-blue-700">
                View Card
            </a>
            
            <a href="apple_wallet_instructions.php?card_number=<?php echo urlencode($card['card_number']); ?>" 
               class="bg-black text-white px-4 py-2 rounded">
                Add to Apple Wallet
            </a>
            
            <?php if (strpos($_SERVER['SERVER_NAME'], 'localhost') !== false || strpos($_SERVER['SERVER_NAME'], '127.0.0.1') !== false): ?>
            <a href="dev_mode_info.php" 
               class="bg-green-600 text-white px-4 py-2 rounded hover:bg-green-700">
                Development Mode
            </a>
            <?php endif; ?>
        </div>
        
        <?php if (!$allImagesExist || !$certExists || !$wwdrExists): ?>
        <div class="mt-4 p-3 bg-yellow-100 text-yellow-800 rounded">
            <p class="font-bold">Warning:</p>
            <p>Some required files are missing. Please run the setup script first:</p>
            <a href="setup_pkpass.php" class="text-blue-600 underline">Run Setup Script</a>
        </div>
        <?php endif; ?>
    </div>
</body>
</html> 