<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start output buffering
ob_start();

// Configuration options
$environments = [
    'local' => [
        'name' => 'Local Development',
        'base_url' => 'http://localhost/erp/',
        'db' => [
            'host' => 'localhost',
            'username' => 'root',
            'password' => '',
            'database' => 'loyalty_card_system'
        ]
    ],
    'live' => [
        'name' => 'Live Server',
        'base_url' => 'https://dev.trimscloud.com/',
        'db' => [
            'host' => 'localhost',
            'username' => 'trimscloud_dev',
            'password' => 'Pakistan@1947',
            'database' => 'trimscloud_dev'
        ]
    ]
];

// Process form submission
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    
    if ($action === 'update_config') {
        $environment = $_POST['environment'] ?? '';
        $customBaseUrl = $_POST['custom_base_url'] ?? '';
        $customDbHost = $_POST['custom_db_host'] ?? '';
        $customDbUser = $_POST['custom_db_user'] ?? '';
        $customDbPass = $_POST['custom_db_pass'] ?? '';
        $customDbName = $_POST['custom_db_name'] ?? '';
        
        if ($environment === 'custom') {
            // Use custom values
            $config = [
                'base_url' => $customBaseUrl,
                'db' => [
                    'host' => $customDbHost,
                    'username' => $customDbUser,
                    'password' => $customDbPass,
                    'database' => $customDbName
                ]
            ];
        } else if (isset($environments[$environment])) {
            // Use predefined environment
            $config = $environments[$environment];
        } else {
            $message = "Invalid environment selected.";
            $messageType = "error";
            goto display_page;
        }
        
        // Update config.php
        if (!updateConfigFile($config)) {
            $message = "Failed to update config file. Check file permissions.";
            $messageType = "error";
            goto display_page;
        }
        
        // Run setup if requested
        if (isset($_POST['run_setup']) && $_POST['run_setup'] === 'yes') {
            $setupResult = runSetup();
            if ($setupResult !== true) {
                $message = "Setup encountered an error: " . $setupResult;
                $messageType = "error";
                goto display_page;
            }
        }
        
        $message = "Configuration updated successfully for " . ($environment === 'custom' ? 'custom environment' : $environments[$environment]['name']);
        $messageType = "success";
        
        // Clear session data if requested
        if (isset($_POST['clear_sessions']) && $_POST['clear_sessions'] === 'yes') {
            clearSessions();
            $message .= " and sessions cleared";
        }
    }
}

display_page:

// Function to update config.php
function updateConfigFile($config) {
    $configPath = __DIR__ . '/setup/config.php';
    
    if (!is_writable($configPath) && file_exists($configPath)) {
        // Try to make it writable
        chmod($configPath, 0666);
        if (!is_writable($configPath)) {
            return false;
        }
    }
    
    $configContent = "<?php
// Base configuration for the Pointify
\$config = [
    // Base URL - change this based on your environment
    'base_url' => '{$config['base_url']}',
    
    // Database configuration
    'db' => [
        'host' => '{$config['db']['host']}',
        'username' => '{$config['db']['username']}',
        'password' => '{$config['db']['password']}',
        'database' => '{$config['db']['database']}'
    ],
    
    // Email configuration for OTP
    'email' => [
        'from' => 'test@trimscloud.com',
        'name' => 'Pointify',
        'smtp' => [
            'host' => 'mail.trimscloud.com',
            'port' => 465,
            'username' => 'test@trimscloud.com',
            'password' => 'Pakistan@1234x',
            'secure' => 'ssl' // Use 'tls' for port 587, 'ssl' for port 465
        ]
    ],
    
    // OTP configuration
    'otp' => [
        'length' => 6,
        'expiry' => 15 // minutes
    ]
];

// Define constants
define('BASE_URL', \$config['base_url']);
define('ADMIN_URL', BASE_URL . 'admin/');
define('CUSTOMER_URL', BASE_URL . 'customer/');
define('ASSETS_URL', BASE_URL . 'assets/');
?>";

    return file_put_contents($configPath, $configContent) !== false;
}

// Function to run setup.php
function runSetup() {
    try {
        // Include the setup file
        ob_start();
        include __DIR__ . '/setup/setup.php';
        $output = ob_get_clean();
        
        if (strpos($output, 'Setup completed successfully') !== false) {
            return true;
        } else {
            return $output;
        }
    } catch (Exception $e) {
        return $e->getMessage();
    }
}

// Function to clear sessions
function clearSessions() {
    // Clear session data
    if (session_status() === PHP_SESSION_ACTIVE) {
        session_destroy();
    }
    
    // Delete session cookies
    if (isset($_COOKIE[session_name()])) {
        setcookie(session_name(), '', time() - 3600, '/');
    }
    
    // Delete all cookies
    foreach ($_COOKIE as $name => $value) {
        setcookie($name, '', time() - 3600, '/');
    }
    
    return true;
}

// Function to check database connection
function testDatabaseConnection($config) {
    try {
        $conn = new PDO(
            "mysql:host={$config['db']['host']};dbname={$config['db']['database']}",
            $config['db']['username'],
            $config['db']['password']
        );
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        return true;
    } catch (PDOException $e) {
        return $e->getMessage();
    }
}

// Get current configuration
$currentConfig = [];
if (file_exists(__DIR__ . '/setup/config.php')) {
    include __DIR__ . '/setup/config.php';
    $currentConfig = $config;
}

// Detect current environment
$currentEnvironment = 'custom';
foreach ($environments as $key => $env) {
    if (isset($currentConfig['base_url']) && $currentConfig['base_url'] === $env['base_url']) {
        $currentEnvironment = $key;
        break;
    }
}

// Test current database connection
$dbConnectionStatus = isset($currentConfig['db']) ? testDatabaseConnection($currentConfig) : false;
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Deployment Helper - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="container mx-auto max-w-4xl">
        <div class="bg-white rounded-lg shadow-md p-6 mb-6">
            <h1 class="text-2xl font-bold mb-4">Pointify - Deployment Helper</h1>
            
            <?php if ($message): ?>
                <div class="<?php echo $messageType === 'error' ? 'bg-red-100 border-red-400 text-red-700' : 'bg-green-100 border-green-400 text-green-700'; ?> px-4 py-3 rounded mb-4 border">
                    <?php echo htmlspecialchars($message); ?>
                </div>
            <?php endif; ?>
            
            <div class="mb-6">
                <h2 class="text-xl font-semibold mb-2">Current Configuration</h2>
                <div class="bg-gray-50 p-4 rounded-lg">
                    <p><strong>Environment:</strong> <?php echo isset($environments[$currentEnvironment]) ? htmlspecialchars($environments[$currentEnvironment]['name']) : 'Custom'; ?></p>
                    <p><strong>Base URL:</strong> <?php echo htmlspecialchars($currentConfig['base_url'] ?? 'Not set'); ?></p>
                    <p><strong>Database:</strong> 
                        <?php if ($dbConnectionStatus === true): ?>
                            <span class="text-green-600">Connected</span>
                        <?php else: ?>
                            <span class="text-red-600">Not connected: <?php echo htmlspecialchars($dbConnectionStatus); ?></span>
                        <?php endif; ?>
                    </p>
                </div>
            </div>
            
            <form method="post" class="space-y-6">
                <input type="hidden" name="action" value="update_config">
                
                <div>
                    <h2 class="text-xl font-semibold mb-2">Select Environment</h2>
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <?php foreach ($environments as $key => $env): ?>
                            <div class="border rounded-lg p-4 <?php echo $currentEnvironment === $key ? 'border-blue-500 bg-blue-50' : 'border-gray-200'; ?>">
                                <label class="flex items-start">
                                    <input type="radio" name="environment" value="<?php echo $key; ?>" <?php echo $currentEnvironment === $key ? 'checked' : ''; ?> class="mt-1 mr-2">
                                    <div>
                                        <div class="font-semibold"><?php echo htmlspecialchars($env['name']); ?></div>
                                        <div class="text-sm text-gray-600"><?php echo htmlspecialchars($env['base_url']); ?></div>
                                        <div class="text-sm text-gray-600">DB: <?php echo htmlspecialchars($env['db']['database']); ?> (<?php echo htmlspecialchars($env['db']['username']); ?>@<?php echo htmlspecialchars($env['db']['host']); ?>)</div>
                                    </div>
                                </label>
                            </div>
                        <?php endforeach; ?>
                        
                        <div class="border rounded-lg p-4 <?php echo $currentEnvironment === 'custom' && !isset($environments[$currentEnvironment]) ? 'border-blue-500 bg-blue-50' : 'border-gray-200'; ?>">
                            <label class="flex items-start">
                                <input type="radio" name="environment" value="custom" <?php echo $currentEnvironment === 'custom' && !isset($environments[$currentEnvironment]) ? 'checked' : ''; ?> class="mt-1 mr-2">
                                <div>
                                    <div class="font-semibold">Custom Environment</div>
                                    <div class="text-sm text-gray-600">Configure your own settings</div>
                                </div>
                            </label>
                        </div>
                    </div>
                </div>
                
                <div id="custom-settings" class="border rounded-lg p-4 <?php echo $currentEnvironment === 'custom' && !isset($environments[$currentEnvironment]) ? 'block' : 'hidden'; ?>">
                    <h3 class="text-lg font-semibold mb-2">Custom Settings</h3>
                    
                    <div class="mb-4">
                        <label for="custom_base_url" class="block text-gray-700 mb-1">Base URL</label>
                        <input type="text" id="custom_base_url" name="custom_base_url" value="<?php echo htmlspecialchars($currentConfig['base_url'] ?? ''); ?>" 
                               class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                               placeholder="https://yourdomain.com/">
                        <p class="text-sm text-gray-500 mt-1">Include trailing slash</p>
                    </div>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div>
                            <label for="custom_db_host" class="block text-gray-700 mb-1">Database Host</label>
                            <input type="text" id="custom_db_host" name="custom_db_host" value="<?php echo htmlspecialchars($currentConfig['db']['host'] ?? ''); ?>" 
                                   class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                                   placeholder="localhost">
                        </div>
                        
                        <div>
                            <label for="custom_db_name" class="block text-gray-700 mb-1">Database Name</label>
                            <input type="text" id="custom_db_name" name="custom_db_name" value="<?php echo htmlspecialchars($currentConfig['db']['database'] ?? ''); ?>" 
                                   class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                                   placeholder="loyalty_card_system">
                        </div>
                        
                        <div>
                            <label for="custom_db_user" class="block text-gray-700 mb-1">Database Username</label>
                            <input type="text" id="custom_db_user" name="custom_db_user" value="<?php echo htmlspecialchars($currentConfig['db']['username'] ?? ''); ?>" 
                                   class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                                   placeholder="root">
                        </div>
                        
                        <div>
                            <label for="custom_db_pass" class="block text-gray-700 mb-1">Database Password</label>
                            <input type="password" id="custom_db_pass" name="custom_db_pass" value="<?php echo htmlspecialchars($currentConfig['db']['password'] ?? ''); ?>" 
                                   class="w-full px-3 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
                                   placeholder="password">
                        </div>
                    </div>
                </div>
                
                <div class="border rounded-lg p-4">
                    <h3 class="text-lg font-semibold mb-2">Additional Options</h3>
                    
                    <div class="space-y-2">
                        <label class="flex items-center">
                            <input type="checkbox" name="run_setup" value="yes" class="mr-2">
                            <span>Run database setup (creates tables and demo data)</span>
                        </label>
                        
                        <label class="flex items-center">
                            <input type="checkbox" name="clear_sessions" value="yes" class="mr-2">
                            <span>Clear all sessions and cookies</span>
                        </label>
                    </div>
                </div>
                
                <button type="submit" class="bg-blue-500 text-white py-2 px-4 rounded-lg hover:bg-blue-600 transition duration-200">
                    Update Configuration
                </button>
            </form>
        </div>
        
        <div class="bg-white rounded-lg shadow-md p-6">
            <h2 class="text-xl font-semibold mb-4">Quick Links</h2>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                <a href="<?php echo htmlspecialchars($currentConfig['base_url'] ?? ''); ?>" class="bg-blue-500 text-white p-3 rounded-lg text-center hover:bg-blue-600 transition">
                    Home Page
                </a>
                
                <a href="<?php echo htmlspecialchars(($currentConfig['base_url'] ?? '') . 'admin/login.php'); ?>" class="bg-green-500 text-white p-3 rounded-lg text-center hover:bg-green-600 transition">
                    Admin Login
                </a>
                
                <a href="<?php echo htmlspecialchars(($currentConfig['base_url'] ?? '') . 'setup/setup.php'); ?>" class="bg-yellow-500 text-white p-3 rounded-lg text-center hover:bg-yellow-600 transition">
                    Run Setup
                </a>
                
                <a href="<?php echo htmlspecialchars(($currentConfig['base_url'] ?? '') . 'session_test.php'); ?>" class="bg-purple-500 text-white p-3 rounded-lg text-center hover:bg-purple-600 transition">
                    Test Sessions
                </a>
                
                <a href="<?php echo htmlspecialchars(($currentConfig['base_url'] ?? '') . 'check_bom.php'); ?>" class="bg-indigo-500 text-white p-3 rounded-lg text-center hover:bg-indigo-600 transition">
                    Check BOM
                </a>
            </div>
        </div>
    </div>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const environmentRadios = document.querySelectorAll('input[name="environment"]');
            const customSettings = document.getElementById('custom-settings');
            
            environmentRadios.forEach(radio => {
                radio.addEventListener('change', function() {
                    if (this.value === 'custom') {
                        customSettings.classList.remove('hidden');
                    } else {
                        customSettings.classList.add('hidden');
                    }
                });
            });
        });
    </script>
</body>
</html>
<?php
// Flush output buffer
ob_end_flush();
?> 