<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
requireLocationAdmin();

$locationId = getCurrentUserLocationId();
$location = getLocationById($locationId);
$customers = getCustomersByLocation($locationId);

// Calculate rewards eligible customers and total points
$rewardsEligible = 0;
$totalPointsAwarded = 0;

foreach ($customers as $customer) {
    // Get reward threshold from location settings
    $rewardThreshold = isset($location['reward_threshold']) ? $location['reward_threshold'] : 10;
    
    // Count customers eligible for rewards
    if (isset($customer['stamp_count']) && $customer['stamp_count'] >= $rewardThreshold) {
        $rewardsEligible++;
    }
    
    // Sum up all stamps awarded
    if (isset($customer['stamp_count'])) {
        $totalPointsAwarded += intval($customer['stamp_count']);
    }
}

// Use the reward threshold from the location data we already have
$reward_threshold = isset($location['reward_threshold']) ? $location['reward_threshold'] : 5;

// Replace the hard-coded 5 with the dynamic reward_threshold
echo '<div class="stamp-card">';
for ($i = 1; $i <= $reward_threshold; $i++) {
    echo '<div class="stamp-circle"></div>';
}
echo '</div>';
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pointify - Location Admin Dashboard</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
            background-color: #f3f4f6;
        }
        .stat-card {
            transition: all 0.3s ease;
            border-radius: 16px;
        }
        .stat-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }
        .action-card {
            transition: all 0.3s ease;
            border-radius: 16px;
        }
        .action-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }
        .table-container {
            border-radius: 16px;
            overflow: hidden;
        }
        .table-header {
            background-color: #f9fafb;
        }
        .dashboard-title {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
        .nav-gradient {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
        }
        .glass-card {
            background: rgba(0, 0, 0, 0.4);
            backdrop-filter: blur(10px);
            border: 1px solid rgba(255, 255, 255, 0.2);
        }
        .custom-shadow {
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
        }
        .glow-on-hover:hover {
            box-shadow: 0 0 15px rgba(79, 70, 229, 0.5);
        }
        .table-row-hover:hover {
            background-color: #f5f7ff;
        }
    </style>
</head>
<body class="bg-gray-50 min-h-screen">
    <!-- Navigation -->
    <nav class="nav-gradient text-white p-4 shadow-lg sticky top-0 z-50">
        <div class="container mx-auto flex justify-between items-center">
            <div class="flex items-center space-x-3">
                <i class="fas fa-id-card-alt text-2xl"></i>
                <h1 class="text-xl font-bold">Pointify</h1>
            </div>
            <div class="flex items-center space-x-6">
                <div class="flex items-center space-x-2">
                    <div class="w-8 h-8 rounded-full bg-indigo-400 flex items-center justify-center">
                        <i class="fas fa-user"></i>
                    </div>
                    <span class="font-medium"><?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                </div>
                <a href="../logout.php" class="bg-white bg-opacity-20 px-4 py-2 rounded-full hover:bg-opacity-30 transition flex items-center">
                    <i class="fas fa-sign-out-alt mr-2"></i> Logout
                </a>
            </div>
        </div>
    </nav>

    <!-- Main Content -->
    <div class="container mx-auto p-6">
        <!-- Welcome Section -->
        <div class="bg-gradient-to-r from-indigo-600 to-purple-600 rounded-3xl shadow-xl p-8 mb-8 text-white relative overflow-hidden">
            <div class="absolute top-0 right-0 w-64 h-64 bg-white opacity-10 rounded-full -mr-20 -mt-20"></div>
            <div class="absolute bottom-0 left-0 w-40 h-40 bg-white opacity-10 rounded-full -ml-10 -mb-10"></div>
            <div class="relative z-10">
                <h2 class="text-3xl font-bold mb-2">Welcome, <?php echo htmlspecialchars($location['name']); ?>!</h2>
                <p class="text-indigo-100 mb-6">Here's what's happening with your loyalty program today.</p>
                
                <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-users text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Total Customers</h3>
                            <p class="text-3xl font-bold text-white"><?php echo count($customers); ?></p>
                        </div>
                    </div>
                    
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-award text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Rewards Eligible</h3>
                            <p class="text-3xl font-bold text-white"><?php echo $rewardsEligible; ?></p>
                        </div>
                    </div>
                    
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-stamp text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Points Awarded</h3>
                            <p class="text-3xl font-bold text-white"><?php echo $totalPointsAwarded; ?></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Quick Actions -->
        <div class="mb-8">
            <h3 class="text-xl font-semibold text-gray-800 mb-6 flex items-center">
                <span class="bg-indigo-100 text-indigo-600 p-2 rounded-lg mr-3">
                    <i class="fas fa-bolt"></i>
                </span>
                Quick Actions
            </h3>
            
            <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                <a href="scan_barcode.php" class="bg-white border border-gray-100 p-6 rounded-2xl text-center transition shadow-md action-card flex flex-col items-center group">
                    <div class="bg-blue-100 text-blue-600 p-4 rounded-2xl mb-4 group-hover:bg-blue-600 group-hover:text-white transition-all">
                        <i class="fas fa-qrcode text-3xl"></i>
                    </div>
                    <h4 class="text-lg font-semibold text-gray-800 mb-2">Scan Barcode</h4>
                    <p class="text-gray-500">Scan a customer's barcode</p>
                </a>
                
                <a href="manage_stamps.php" class="bg-white border border-gray-100 p-6 rounded-2xl text-center transition shadow-md action-card flex flex-col items-center group">
                    <div class="bg-green-100 text-green-600 p-4 rounded-2xl mb-4 group-hover:bg-green-600 group-hover:text-white transition-all">
                        <i class="fas fa-stamp text-3xl"></i>
                    </div>
                    <h4 class="text-lg font-semibold text-gray-800 mb-2">Manage Stamps</h4>
                    <p class="text-gray-500">Manage customer stamps</p>
                </a>

                <a href="registration_link.php" class="bg-white border border-gray-100 p-6 rounded-2xl text-center transition shadow-md action-card flex flex-col items-center group">
                    <div class="bg-purple-100 text-purple-600 p-4 rounded-2xl mb-4 group-hover:bg-purple-600 group-hover:text-white transition-all">
                        <i class="fas fa-link text-3xl"></i>
                    </div>
                    <h4 class="text-lg font-semibold text-gray-800 mb-2">Registration Link</h4>
                    <p class="text-gray-500">Share registration link</p>
                </a>
            </div>
        </div>

        <!-- Recent Customers -->
        <div class="bg-white rounded-2xl shadow-md p-6 border border-gray-100">
            <div class="flex justify-between items-center mb-6">
                <h2 class="text-2xl font-bold text-gray-800 flex items-center">
                    <span class="bg-green-100 text-green-600 p-2 rounded-lg mr-3">
                        <i class="fas fa-users"></i>
                    </span>
                    Recent Customers
                </h2>
            </div>
            
            <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                <table class="min-w-full bg-white">
                    <thead class="bg-gray-50">
                        <tr>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Email</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Card Number</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Stamps</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Rewards</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php 
                        $recentCustomers = array_slice($customers, 0, 10);
                        foreach ($recentCustomers as $customer): 
                        ?>
                        <tr class="table-row-hover transition">
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['email']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['card_number']); ?></td>
                            <td class="py-4 px-6 border-b">
                                <div class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-full w-max">
                                    <?php echo htmlspecialchars($customer['stamp_count']); ?> <i class="fas fa-stamp text-xs ml-1"></i>
                                </div>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <?php if (isset($customer['rewards_earned']) && $customer['rewards_earned'] > 0): ?>
                                <span class="bg-yellow-100 text-yellow-600 px-2 py-1 rounded-full text-xs flex items-center w-max">
                                    <i class="fas fa-award mr-1"></i> <?php echo $customer['rewards_earned']; ?>
                                </span>
                                <?php else: ?>
                                <span class="text-gray-400">-</span>
                                <?php endif; ?>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <div class="flex space-x-3">
                                    <a href="../../customer/card.php?card_number=<?php echo urlencode($customer['card_number']); ?>" 
                                       class="bg-blue-100 text-blue-600 px-3 py-1 rounded-lg hover:bg-blue-200 transition flex items-center">
                                        <i class="fas fa-eye mr-1"></i> View
                                    </a>
                                    <a href="manage_stamps.php?customer_id=<?php echo urlencode($customer['id']); ?>" 
                                       class="bg-green-100 text-green-600 px-3 py-1 rounded-lg hover:bg-green-200 transition flex items-center">
                                        <i class="fas fa-stamp mr-1"></i> Stamps
                                    </a>
                                </div>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                        
                        <?php if (empty($recentCustomers)): ?>
                        <tr>
                            <td colspan="6" class="py-8 text-center text-gray-500">
                                <div class="flex flex-col items-center">
                                    <div class="bg-gray-100 p-4 rounded-full mb-3">
                                        <i class="fas fa-user-slash text-3xl text-gray-400"></i>
                                    </div>
                                    <p>No customers found</p>
                                </div>
                            </td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <footer class="bg-white py-6 border-t mt-8">
        <div class="container mx-auto px-6 text-center">
            <p class="text-gray-500 text-sm">© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </footer>
</body>
</html> 