<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
requireSuperAdmin();

// Get database connection from auth.php
global $conn;

// If $conn is still not available, try to establish the connection directly
if (!isset($conn)) {
    // This is a fallback - adjust these values to match your actual database configuration
    $host = 'localhost';
    $username = 'root';
    $password = '';
    $database = 'loyalty_card_system'; // Replace with your actual database name
    
    $conn = mysqli_connect($host, $username, $password, $database);
    
    if (!$conn) {
        die("Database connection failed: " . mysqli_connect_error());
    }
}

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error_message'] = "Location ID is required";
    header("Location: dashboard.php");
    exit();
}

$location_id = $_GET['id'];
$location = getLocationById($location_id);

// If location doesn't exist, redirect back to dashboard
if (!$location) {
    $_SESSION['error_message'] = "Location not found";
    header("Location: dashboard.php");
    exit();
}

// Handle form submission
if (isset($_POST['edit_location'])) {
    $location_name = $_POST['location_name'];
    $location_address = $_POST['location_address'];
    $location_slug = $_POST['location_slug'];
    $reward_threshold = $_POST['reward_threshold'];
    
    // Update the location in the database - removing the address field since it doesn't exist
    $update_query = "UPDATE locations SET 
                    name = '$location_name', 
                    slug = '$location_slug',
                    reward_threshold = '$reward_threshold'
                    WHERE id = $location_id";
                    
    if (mysqli_query($conn, $update_query)) {
        $_SESSION['success_message'] = "Location updated successfully!";
        header("Location: dashboard.php");
        exit();
    } else {
        $_SESSION['error_message'] = "Failed to update location: " . mysqli_error($conn);
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Location - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
            background-color: #f3f4f6;
        }
        .nav-gradient {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
        }
    </style>
</head>
<body class="bg-gray-50 min-h-screen">
    <!-- Navigation -->
    <nav class="nav-gradient text-white p-4 shadow-lg sticky top-0 z-50">
        <div class="container mx-auto flex justify-between items-center">
            <div class="flex items-center space-x-3">
                <i class="fas fa-id-card-alt text-2xl"></i>
                <h1 class="text-xl font-bold">Pointify</h1>
            </div>
            <div class="flex items-center space-x-6">
                <div class="flex items-center space-x-2">
                    <div class="w-8 h-8 rounded-full bg-indigo-400 flex items-center justify-center">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="font-medium"><?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                </div>
                <a href="../logout.php" class="bg-white bg-opacity-20 px-4 py-2 rounded-full hover:bg-opacity-30 transition flex items-center">
                    <i class="fas fa-sign-out-alt mr-2"></i> Logout
                </a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-6">
        <div class="bg-white rounded-2xl shadow-md p-8 max-w-3xl mx-auto">
            <div class="flex items-center mb-6">
                <a href="dashboard.php" class="text-indigo-600 hover:text-indigo-800 mr-4">
                    <i class="fas fa-arrow-left"></i> Back to Dashboard
                </a>
                <h2 class="text-2xl font-bold text-gray-800">Edit Location</h2>
            </div>
            
            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6 rounded">
                    <div class="flex items-center">
                        <i class="fas fa-exclamation-circle mr-2"></i>
                        <p><?php echo $_SESSION['error_message']; unset($_SESSION['error_message']); ?></p>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-6 rounded">
                    <div class="flex items-center">
                        <i class="fas fa-check-circle mr-2"></i>
                        <p><?php echo $_SESSION['success_message']; unset($_SESSION['success_message']); ?></p>
                    </div>
                </div>
            <?php endif; ?>
            
            <form method="POST" action="" class="space-y-6">
                <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                        <label for="location_name" class="block text-sm font-medium text-gray-700 mb-2">Location Name</label>
                        <input type="text" id="location_name" name="location_name" value="<?php echo htmlspecialchars($location['name']); ?>" 
                               class="w-full px-4 py-2 border border-gray-300 rounded-lg focus:ring-indigo-500 focus:border-indigo-500" required>
                    </div>
                    
                    <div>
                        <label for="location_slug" class="block text-sm font-medium text-gray-700 mb-2">Location Slug</label>
                        <input type="text" id="location_slug" name="location_slug" value="<?php echo htmlspecialchars($location['slug']); ?>" 
                               class="w-full px-4 py-2 border border-gray-300 rounded-lg focus:ring-indigo-500 focus:border-indigo-500" required>
                        <p class="text-sm text-gray-500 mt-1">Used in URLs, no spaces or special characters</p>
                    </div>
                </div>
                
                <div>
                    <label for="reward_threshold" class="block text-sm font-medium text-gray-700 mb-2">Reward Threshold</label>
                    <input type="number" id="reward_threshold" name="reward_threshold" value="<?php echo htmlspecialchars($location['reward_threshold']); ?>" 
                           class="w-full px-4 py-2 border border-gray-300 rounded-lg focus:ring-indigo-500 focus:border-indigo-500" required min="1">
                    <p class="text-sm text-gray-500 mt-1">Number of stamps needed for a reward</p>
                </div>
                
                <div class="pt-4">
                    <button type="submit" name="edit_location" class="w-full bg-indigo-600 hover:bg-indigo-700 text-white font-medium py-3 px-4 rounded-lg transition flex items-center justify-center">
                        <i class="fas fa-save mr-2"></i> Update Location
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-white py-6 border-t mt-8">
        <div class="container mx-auto px-6 text-center">
            <p class="text-gray-500 text-sm">© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </footer>
</body>
</html> 