<?php
// Extremely simple wallet landing page
require_once '../includes/functions.php';

// Check for card number
if (!isset($_GET['card_number'])) {
    die("Card number is required");
}

$cardNumber = $_GET['card_number'];

// Get basic card details
try {
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT lc.card_number, c.name, l.name as location_name
        FROM loyalty_cards lc
        JOIN customers c ON lc.customer_id = c.id
        JOIN locations l ON c.location_id = l.id
        WHERE lc.card_number = :card_number
    ");
    $stmt->bindParam(':card_number', $cardNumber);
    $stmt->execute();
    $card = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$card) {
        die("Invalid card number");
    }
} catch (Exception $e) {
    die("Database error");
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add to Apple Wallet</title>
    <style>
        body {
            font-family: -apple-system, BlinkMacSystemFont, sans-serif;
            margin: 0;
            padding: 20px;
            text-align: center;
            background-color: #f5f5f7;
            color: #333;
            line-height: 1.5;
        }
        .container {
            max-width: 400px;
            margin: 0 auto;
            background: white;
            border-radius: 10px;
            padding: 20px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.05);
        }
        h1 {
            margin-top: 0;
            font-size: 24px;
        }
        .card-info {
            margin: 20px 0;
            text-align: left;
            background: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
        }
        .btn {
            display: inline-block;
            background-color: #000;
            color: white;
            padding: 15px 30px;
            border-radius: 10px;
            text-decoration: none;
            font-weight: 600;
            margin: 20px 0;
            width: 100%;
            box-sizing: border-box;
        }
        .note {
            font-size: 14px;
            color: #666;
            margin-top: 20px;
        }
        .back {
            color: #06c;
            text-decoration: none;
            display: inline-block;
            margin-top: 15px;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Add to Apple Wallet</h1>
        
        <div class="card-info">
            <p><strong>Card:</strong> <?php echo htmlspecialchars($card['card_number']); ?></p>
            <p><strong>Name:</strong> <?php echo htmlspecialchars($card['name']); ?></p>
            <p><strong>Location:</strong> <?php echo htmlspecialchars($card['location_name']); ?></p>
        </div>
        
        <a href="extreme_simple_pass.php?card_number=<?php echo urlencode($cardNumber); ?>" class="btn">
            Download Wallet Pass
        </a>
        
        <div class="note">
            After downloading, open the file to add it to your Apple Wallet.
        </div>
        
        <a href="card.php?card_number=<?php echo urlencode($cardNumber); ?>" class="back">
            Return to Card
        </a>
    </div>
</body>
</html> 