<?php
/**
 * Minimal Wallet Page
 * 
 * A stripped-down page with just the essentials for downloading a PKPass file.
 */

require_once '../includes/functions.php';

// Check for card number parameter
if (!isset($_GET['card_number'])) {
    die("Card number is required");
}

$cardNumber = $_GET['card_number'];

// Get card details from database
try {
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT lc.card_number, c.name, l.name as location_name
        FROM loyalty_cards lc
        JOIN customers c ON lc.customer_id = c.id
        JOIN locations l ON c.location_id = l.id
        WHERE lc.card_number = :card_number
    ");
    $stmt->bindParam(':card_number', $cardNumber);
    $stmt->execute();
    $card = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$card) {
        die("Invalid card number");
    }
} catch (Exception $e) {
    die("Database error");
}

// Generate URL for the PKPass download
$passUrl = "ultra_simple_pass.php?card_number=" . urlencode($cardNumber);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add to Apple Wallet - <?php echo htmlspecialchars($card['location_name']); ?></title>
    <style>
        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f5f5f7;
            color: #1d1d1f;
            line-height: 1.5;
        }
        .container {
            max-width: 600px;
            margin: 0 auto;
            padding: 20px;
        }
        .card {
            background: white;
            border-radius: 12px;
            padding: 24px;
            margin-top: 20px;
            box-shadow: 0 2px 8px rgba(0,0,0,0.06);
        }
        h1 {
            font-size: 24px;
            font-weight: 600;
            margin-bottom: 16px;
        }
        p {
            margin-bottom: 16px;
        }
        .wallet-button {
            display: block;
            width: 100%;
            background-color: #000;
            color: white;
            border: none;
            border-radius: 8px;
            padding: 15px;
            font-size: 16px;
            font-weight: 500;
            text-align: center;
            cursor: pointer;
            text-decoration: none;
            margin: 24px 0;
        }
        .wallet-button:hover {
            background-color: #333;
        }
        .back-link {
            display: block;
            text-align: center;
            margin-top: 24px;
            color: #0066cc;
            text-decoration: none;
        }
        .note {
            background-color: #f8f8f8;
            border-radius: 8px;
            padding: 16px;
            font-size: 14px;
            color: #666;
            margin-top: 24px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="card">
            <h1>Add to Apple Wallet</h1>
            
            <p>Loyalty card for: <strong><?php echo htmlspecialchars($card['name']); ?></strong></p>
            <p>Location: <strong><?php echo htmlspecialchars($card['location_name']); ?></strong></p>
            
            <a href="<?php echo htmlspecialchars($passUrl); ?>" class="wallet-button">
                Download Pass
            </a>
            
            <div class="note">
                <strong>Instructions:</strong>
                <ol>
                    <li>Click the button above to download the pass</li>
                    <li>When prompted, choose "Add to Wallet & Apple Pay"</li>
                    <li>Your loyalty card will be added to Apple Wallet</li>
                </ol>
                
                <p style="margin-top: 16px; margin-bottom: 0;">If you have any issues, please contact customer support.</p>
            </div>
        </div>
        
        <a href="card.php?card_number=<?php echo urlencode($cardNumber); ?>" class="back-link">
            Return to Loyalty Card
        </a>
    </div>
</body>
</html> 