<?php
require_once '../includes/functions.php';

// Check if location parameter is provided
if (!isset($_GET['location'])) {
    die("Location parameter is required");
}

$locationSlug = $_GET['location'];
$location = getLocationBySlug($locationSlug);

if (!$location) {
    die("Invalid location");
}

$error = '';
$success = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name'] ?? '');
    $email = trim($_POST['email'] ?? '');
    
    if (empty($name) || empty($email)) {
        $error = "Please fill in all fields";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "Please enter a valid email address";
    } else {
        // Create customer
        $result = createCustomer($name, $email, $location['id']);
        
        if ($result['success']) {
            // Generate OTP
            $otp = generateOTP($config['otp']['length']);
            
            // Store OTP
            storeOTP($result['customer_id'], $otp, $config['otp']['expiry']);
            
            // Send OTP email
            sendOTPEmail($email, $name, $otp);
            
            // Redirect to OTP verification page
            header("Location: verify_otp.php?customer_id=" . $result['customer_id']);
            exit;
        } else {
            $error = $result['message'];
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register for Loyalty Card - <?php echo htmlspecialchars($location['name']); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex items-center justify-center">
    <div class="bg-white p-8 rounded-lg shadow-md w-full max-w-md">
        <h1 class="text-2xl font-bold text-center mb-6">Register for Loyalty Card</h1>
        <h2 class="text-xl text-center mb-6 text-gray-600"><?php echo htmlspecialchars($location['name']); ?></h2>
        
        <?php if ($error): ?>
            <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded mb-4">
                <?php echo htmlspecialchars($error); ?>
            </div>
        <?php endif; ?>
        
        <form method="post" class="space-y-4">
            <div>
                <label for="name" class="block text-gray-700 mb-2">Full Name</label>
                <input type="text" id="name" name="name" required 
                    class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500">
            </div>
            
            <div>
                <label for="email" class="block text-gray-700 mb-2">Email Address</label>
                <input type="email" id="email" name="email" required 
                    class="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500">
            </div>
            
            <button type="submit" class="w-full bg-blue-500 text-white py-2 px-4 rounded-lg hover:bg-blue-600 transition duration-200">
                Register
            </button>
        </form>
    </div>
</body>
</html> 