<?php
require_once '../includes/functions.php';

// Check for card number parameter
if (!isset($_GET['card_number'])) {
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT lc.card_number, c.name, l.name as location_name
        FROM loyalty_cards lc
        JOIN customers c ON lc.customer_id = c.id
        JOIN locations l ON c.location_id = l.id
        LIMIT 1
    ");
    $stmt->execute();
    $card = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($card) {
        $cardNumber = $card['card_number'];
    } else {
        die("No loyalty cards found in database. Please create a card first.");
    }
} else {
    $cardNumber = $_GET['card_number'];
    
    // Get card details
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT lc.card_number, c.name, l.name as location_name
        FROM loyalty_cards lc
        JOIN customers c ON lc.customer_id = c.id
        JOIN locations l ON c.location_id = l.id
        WHERE lc.card_number = :card_number
    ");
    $stmt->bindParam(':card_number', $cardNumber);
    $stmt->execute();
    $card = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$card) {
        die("Invalid card number");
    }
}

// Generate URLs
$baseUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]";
$passDownloadUrl = $baseUrl . "/customer/simple_pkpass_download.php?card_number=" . urlencode($cardNumber);
$qrCodeUrl = "https://api.qrserver.com/v1/create-qr-code/?size=200x200&data=" . urlencode($passDownloadUrl);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add to Apple Wallet - <?php echo htmlspecialchars($card['location_name']); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        .apple-wallet-button {
            background-color: black;
            color: white;
            border-radius: 6px;
            padding: 12px 16px;
            display: inline-flex;
            align-items: center;
            font-size: 16px;
            font-weight: 500;
            gap: 8px;
        }
        .apple-wallet-button:hover {
            background-color: #333;
        }
        .apple-logo {
            width: 20px;
            height: 20px;
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex items-center justify-center p-4">
    <div class="max-w-lg w-full bg-white rounded-lg shadow-md overflow-hidden">
        <div class="bg-blue-600 text-white p-6">
            <h1 class="text-2xl font-bold">Add to Apple Wallet</h1>
            <p class="mt-1">Multiple ways to add your loyalty card</p>
        </div>
        
        <div class="p-6">
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Card Details</h2>
                <p><strong>Card Number:</strong> <?php echo htmlspecialchars($cardNumber); ?></p>
                <p><strong>Customer:</strong> <?php echo htmlspecialchars($card['name']); ?></p>
                <p><strong>Location:</strong> <?php echo htmlspecialchars($card['location_name']); ?></p>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 1: Direct Download</h2>
                <p class="mb-4">Click the button below to download the pass directly:</p>
                
                <a href="<?php echo htmlspecialchars($passDownloadUrl); ?>" class="apple-wallet-button">
                    <svg class="apple-logo" viewBox="0 0 24 24" fill="white" xmlns="http://www.w3.org/2000/svg">
                        <path d="M17.0448 12.0965C17.0367 10.1391 18.1778 8.6492 20.4886 7.7231C19.3305 6.0572 17.5843 5.0965 15.331 4.9619C13.1939 4.8301 10.8166 6.3355 10.0302 6.3355C9.1896 6.3355 7.0823 5.0172 5.4465 5.0172C2.8053 5.0607 0 7.3012 0 11.8917C0 13.1664 0.235397 14.4874 0.706029 15.8539C1.34113 17.6755 3.96519 22.9631 6.70461 22.8721C7.97998 22.8339 8.89472 21.8733 10.5871 21.8733C12.2233 21.8733 13.0657 22.8721 14.4865 22.8721C17.2512 22.8285 19.6405 18.0111 20.2422 16.1825C16.8444 14.6253 17.0448 12.1664 17.0448 12.0965Z"/>
                        <path d="M13.9518 3.66428C15.0376 2.34447 14.848 1.12278 14.7841 0.55957C13.7647 0.622059 12.5775 1.25913 11.8639 2.01399C11.0693 2.85033 10.5925 3.89552 10.6988 4.9619C11.8147 5.0609 12.8662 4.98443 13.9518 3.66428Z"/>
                    </svg>
                    Add to Apple Wallet
                </a>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 2: Scan QR Code</h2>
                <p class="mb-4">Scan this QR code with your iPhone camera:</p>
                
                <div class="flex justify-center mb-4">
                    <img src="<?php echo $qrCodeUrl; ?>" alt="QR Code" class="border border-gray-300 rounded-lg">
                </div>
                
                <ol class="list-decimal pl-6 mb-4 space-y-2">
                    <li>Open your iPhone camera</li>
                    <li>Point it at the QR code above</li>
                    <li>Tap the notification that appears</li>
                    <li>Follow the prompts to add to Apple Wallet</li>
                </ol>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 3: Email Method</h2>
                <p class="mb-4">Send the pass to your email:</p>
                
                <form class="flex flex-col md:flex-row gap-2">
                    <input type="email" placeholder="Enter your email" class="flex-grow p-3 border rounded">
                    <button type="button" class="bg-blue-600 text-white px-4 py-2 rounded">Send Pass</button>
                </form>
                <p class="text-sm text-gray-500 mt-2">We'll email you the pass which you can open directly on your iOS device.</p>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 4: Ultra Simple Method</h2>
                <p class="mb-4">Try this minimal version if you're having trouble with the other methods:</p>
                
                <a href="minimal_wallet.php?card_number=<?php echo urlencode($cardNumber); ?>" class="bg-orange-500 text-white px-4 py-2 rounded inline-block hover:bg-orange-600">
                    Try Ultra Simple Method
                </a>
                <p class="text-sm text-gray-500 mt-2">This uses a stripped-down approach that may work better on some devices.</p>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 5: Extreme Simplified Method</h2>
                <p class="mb-4">If nothing else works, try this extremely simplified approach:</p>
                
                <a href="extreme_simple_wallet.php?card_number=<?php echo urlencode($cardNumber); ?>" class="bg-red-500 text-white px-4 py-2 rounded inline-block hover:bg-red-600">
                    Try Extreme Simple Method
                </a>
                <p class="text-sm text-gray-500 mt-2">This bypasses all OpenSSL requirements with a bare-bones implementation.</p>
            </div>
            
            <div class="mb-6">
                <h2 class="text-lg font-bold text-gray-700 mb-2">Option 6: Final Direct Method</h2>
                <p class="mb-4">Our absolute simplest approach - try this as a last resort:</p>
                
                <a href="final_wallet.php?card_number=<?php echo urlencode($cardNumber); ?>" class="bg-purple-600 text-white px-4 py-2 rounded inline-block hover:bg-purple-700">
                    Try Final Method
                </a>
                <p class="text-sm text-gray-500 mt-2">The most minimalist implementation possible with basic compatibility.</p>
            </div>
            
            <div class="mt-6 flex justify-between">
                <a href="card.php?card_number=<?php echo urlencode($cardNumber); ?>" class="px-4 py-2 bg-gray-200 text-gray-800 rounded-lg hover:bg-gray-300">
                    Back to Card
                </a>
                
                <?php if (strpos($_SERVER['SERVER_NAME'], 'localhost') !== false || strpos($_SERVER['SERVER_NAME'], '127.0.0.1') !== false): ?>
                <a href="dev_mode_info.php" class="px-4 py-2 bg-green-600 text-white rounded-lg hover:bg-green-700">
                    Development Mode
                </a>
                <?php endif; ?>
            </div>
        </div>
    </div>
</body>
</html> 