<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
requireSuperAdmin();

$locations = getAllLocations();
$locationFilter = isset($_GET['location_id']) && !empty($_GET['location_id']) ? (int)$_GET['location_id'] : null;

// Get customers with optional location filter
if ($locationFilter) {
    $customers = getCustomersByLocation($locationFilter);
    // Get the current location name for display
    $currentLocation = null;
    foreach ($locations as $location) {
        if ($location['id'] == $locationFilter) {
            $currentLocation = $location['name'];
            break;
        }
    }
} else {
    $customers = getAllCustomers();
    $currentLocation = "All Locations";
}

// Total customers count
$totalCustomers = count($customers);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>All Customers - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
            background-color: #f3f4f6;
        }
        .nav-gradient {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
        }
        .table-container {
            border-radius: 16px;
            overflow: hidden;
        }
        .table-row-hover:hover {
            background-color: #f5f7ff;
        }
    </style>
</head>
<body class="bg-gray-50 min-h-screen">
    <!-- Navigation -->
    <nav class="nav-gradient text-white p-4 shadow-lg sticky top-0 z-50">
        <div class="container mx-auto flex justify-between items-center">
            <div class="flex items-center space-x-3">
                <i class="fas fa-id-card-alt text-2xl"></i>
                <h1 class="text-xl font-bold">Pointify</h1>
            </div>
            <div class="flex items-center space-x-6">
                <div class="flex items-center space-x-2">
                    <div class="w-8 h-8 rounded-full bg-indigo-400 flex items-center justify-center">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="font-medium"><?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                </div>
                <a href="../logout.php" class="bg-white bg-opacity-20 px-4 py-2 rounded-full hover:bg-opacity-30 transition flex items-center">
                    <i class="fas fa-sign-out-alt mr-2"></i> Logout
                </a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-6">
        <!-- Breadcrumb -->
        <div class="flex items-center mb-6 text-sm">
            <a href="dashboard.php" class="text-indigo-600 hover:text-indigo-800">Dashboard</a>
            <i class="fas fa-chevron-right mx-2 text-gray-400 text-xs"></i>
            <span class="text-gray-700">All Customers</span>
        </div>
        
        <!-- Customers List -->
        <div class="bg-white rounded-2xl shadow-md p-6 mb-8 border border-gray-100">
            <div class="flex justify-between items-center mb-6">
                <div>
                    <h2 class="text-2xl font-bold text-gray-800 flex items-center">
                        <span class="bg-green-100 text-green-600 p-2 rounded-lg mr-3">
                            <i class="fas fa-users"></i>
                        </span>
                        Customers - <?php echo htmlspecialchars($currentLocation); ?>
                    </h2>
                    <p class="text-gray-500 mt-1">Total: <?php echo $totalCustomers; ?> customers</p>
                </div>
                
                <form action="" method="GET" class="flex items-center">
                    <select name="location_id" class="border border-gray-300 rounded-lg px-3 py-2 focus:outline-none focus:ring-2 focus:ring-indigo-500">
                        <option value="">All Locations</option>
                        <?php foreach ($locations as $location): ?>
                        <option value="<?php echo $location['id']; ?>" <?php echo ($locationFilter == $location['id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($location['name']); ?>
                        </option>
                        <?php endforeach; ?>
                    </select>
                    <button type="submit" class="bg-indigo-600 text-white px-4 py-2 rounded-lg hover:bg-indigo-700 transition ml-2">
                        <i class="fas fa-filter mr-1"></i> Filter
                    </button>
                </form>
            </div>
            
            <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                <table class="min-w-full bg-white">
                    <thead class="bg-gray-50">
                        <tr>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Email</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Location</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Card Number</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Stamps</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($customers as $customer): ?>
                        <tr class="table-row-hover transition">
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['email']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['location_name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['card_number'] ?? 'N/A'); ?></td>
                            <td class="py-4 px-6 border-b">
                                <div class="flex items-center">
                                    <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] > 0): ?>
                                    <div class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-full flex items-center">
                                        <span class="mr-1"><?php echo $customer['stamp_count'] ?? '0'; ?></span>
                                        <i class="fas fa-stamp text-xs"></i>
                                    </div>
                                    <?php else: ?>
                                    <span class="text-gray-500">0</span>
                                    <?php endif; ?>
                                    
                                    <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] >= 10): ?>
                                    <span class="ml-2 bg-yellow-100 text-yellow-600 px-2 py-1 rounded-full text-xs flex items-center">
                                        <i class="fas fa-award mr-1"></i> Reward
                                    </span>
                                    <?php endif; ?>
                                </div>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <?php if (!empty($customer['card_number'])): ?>
                                <a href="../../customer/card.php?card_number=<?php echo urlencode($customer['card_number']); ?>" 
                                   class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-lg hover:bg-indigo-200 transition flex items-center w-max" target="_blank">
                                    <i class="fas fa-id-card mr-1"></i> View Card
                                </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                        
                        <?php if (empty($customers)): ?>
                        <tr>
                            <td colspan="6" class="py-8 text-center text-gray-500">
                                <div class="flex flex-col items-center">
                                    <div class="bg-gray-100 p-4 rounded-full mb-3">
                                        <i class="fas fa-user-slash text-3xl text-gray-400"></i>
                                    </div>
                                    <p>No customers found</p>
                                </div>
                            </td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-white py-6 border-t mt-8">
        <div class="container mx-auto px-6 text-center">
            <p class="text-gray-500 text-sm">© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </footer>
</body>
</html> 