<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../../includes/auth.php';
requireSuperAdmin();

$locations = getAllLocations();
$customers = getAllCustomers();
$locationAdmins = getAllLocationAdmins();

// Calculate total customers
$totalCustomers = count($customers);

// Calculate total locations
$totalLocations = count($locations);

// Calculate customers with rewards
$customersWithRewards = 0;
foreach ($customers as $customer) {
    if (isset($customer['stamp_count']) && $customer['stamp_count'] >= 10) {
        $customersWithRewards++;
    }
}

// Check if the location edit form is properly defined
if(isset($_POST['edit_location'])) {
    $location_id = $_POST['location_id'];
    $location_name = $_POST['location_name'];
    $location_address = $_POST['location_address'];
    
    // Update the location in the database
    $update_query = "UPDATE locations SET name = '$location_name', address = '$location_address' WHERE id = $location_id";
    if(mysqli_query($conn, $update_query)) {
        $_SESSION['success_message'] = "Location updated successfully!";
    } else {
        $_SESSION['error_message'] = "Failed to update location: " . mysqli_error($conn);
    }
    
    // Redirect to refresh the page
    header("Location: dashboard.php");
    exit();
}

// Make sure the location edit form is properly displayed
function displayLocationEditForm($location_id) {
    global $conn;
    
    $query = "SELECT * FROM locations WHERE id = $location_id";
    $result = mysqli_query($conn, $query);
    
    if(mysqli_num_rows($result) > 0) {
        $location = mysqli_fetch_assoc($result);
        ?>
        <form method="POST" action="">
            <input type="hidden" name="location_id" value="<?php echo $location['id']; ?>">
            <div class="form-group">
                <label>Location Name</label>
                <input type="text" class="form-control" name="location_name" value="<?php echo $location['name']; ?>" required>
            </div>
            <div class="form-group">
                <label>Address</label>
                <textarea class="form-control" name="location_address" required><?php echo $location['address']; ?></textarea>
            </div>
            <button type="submit" name="edit_location" class="btn btn-primary">Update Location</button>
        </form>
        <?php
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pointify - Admin Dashboard</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <!-- Font Awesome for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
            background-color: #f3f4f6;
        }
        .stat-card {
            transition: all 0.3s ease;
            border-radius: 16px;
        }
        .stat-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }
        .action-card {
            transition: all 0.3s ease;
            border-radius: 16px;
        }
        .action-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }
        .table-container {
            border-radius: 16px;
            overflow: hidden;
        }
        .table-header {
            background-color: #f9fafb;
        }
        .dashboard-title {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
        .nav-gradient {
            background: linear-gradient(90deg, #4f46e5, #8b5cf6);
        }
        .glass-card {
            background: rgba(0, 0, 0, 0.4);
            backdrop-filter: blur(10px);
            border: 1px solid rgba(255, 255, 255, 0.2);
        }
        .custom-shadow {
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
        }
        .glow-on-hover:hover {
            box-shadow: 0 0 15px rgba(79, 70, 229, 0.5);
        }
        .table-row-hover:hover {
            background-color: #f5f7ff;
        }
    </style>
</head>
<body class="bg-gray-50 min-h-screen">
    <!-- Navigation -->
    <nav class="nav-gradient text-white p-4 shadow-lg sticky top-0 z-50">
        <div class="container mx-auto flex justify-between items-center">
            <div class="flex items-center space-x-3">
                <i class="fas fa-id-card-alt text-2xl"></i>
                <h1 class="text-xl font-bold">Pointify</h1>
            </div>
            <div class="flex items-center space-x-6">
                <div class="flex items-center space-x-2">
                    <div class="w-8 h-8 rounded-full bg-indigo-400 flex items-center justify-center">
                        <i class="fas fa-user-shield"></i>
                    </div>
                    <span class="font-medium"><?php echo htmlspecialchars($_SESSION['user_name']); ?></span>
                </div>
                <a href="../logout.php" class="bg-white bg-opacity-20 px-4 py-2 rounded-full hover:bg-opacity-30 transition flex items-center">
                    <i class="fas fa-sign-out-alt mr-2"></i> Logout
                </a>
            </div>
        </div>
    </nav>
    
    <!-- Main Content -->
    <div class="container mx-auto p-6">
        <!-- Welcome Section -->
        <div class="bg-gradient-to-r from-indigo-600 to-purple-600 rounded-3xl shadow-xl p-8 mb-8 text-white relative overflow-hidden">
            <div class="absolute top-0 right-0 w-64 h-64 bg-white opacity-10 rounded-full -mr-20 -mt-20"></div>
            <div class="absolute bottom-0 left-0 w-40 h-40 bg-white opacity-10 rounded-full -ml-10 -mb-10"></div>
            <div class="relative z-10">
                <h2 class="text-3xl font-bold mb-2">Welcome, <?php echo htmlspecialchars($_SESSION['user_name']); ?>!</h2>
                <p class="text-indigo-100 mb-6">Here's what's happening with your loyalty program today.</p>
                
                <div class="grid grid-cols-1 md:grid-cols-3 gap-6">
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-store text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Total Locations</h3>
                            <p class="text-3xl font-bold text-white"><?php echo $totalLocations; ?></p>
                        </div>
                    </div>
                    
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-users text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Total Customers</h3>
                            <p class="text-3xl font-bold text-white"><?php echo $totalCustomers; ?></p>
                        </div>
                    </div>
                    
                    <div class="glass-card p-6 rounded-2xl flex items-center">
                        <div class="bg-white text-indigo-600 p-3 rounded-xl mr-4">
                            <i class="fas fa-award text-xl"></i>
                        </div>
                        <div>
                            <h3 class="text-sm font-semibold text-white uppercase tracking-wider mb-1">Rewards Eligible</h3>
                            <p class="text-3xl font-bold text-white"><?php echo $customersWithRewards; ?></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Quick Actions -->
        <div class="mb-8">
            <h3 class="text-xl font-semibold text-gray-800 mb-6 flex items-center">
                <span class="bg-indigo-100 text-indigo-600 p-2 rounded-lg mr-3">
                    <i class="fas fa-bolt"></i>
                </span>
                Quick Actions
            </h3>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
                <a href="create_location.php" class="bg-white border border-gray-100 p-6 rounded-2xl text-center transition shadow-md action-card flex flex-col items-center group">
                    <div class="bg-green-100 text-green-600 p-4 rounded-2xl mb-4 group-hover:bg-green-600 group-hover:text-white transition-all">
                        <i class="fas fa-plus-circle text-3xl"></i>
                    </div>
                    <h4 class="text-lg font-semibold text-gray-800 mb-2">Create Location</h4>
                    <p class="text-gray-500">Add a new business location</p>
                </a>
                
                <a href="create_admin.php" class="bg-white border border-gray-100 p-6 rounded-2xl text-center transition shadow-md action-card flex flex-col items-center group">
                    <div class="bg-indigo-100 text-indigo-600 p-4 rounded-2xl mb-4 group-hover:bg-indigo-600 group-hover:text-white transition-all">
                        <i class="fas fa-user-plus text-3xl"></i>
                    </div>
                    <h4 class="text-lg font-semibold text-gray-800 mb-2">Create Admin</h4>
                    <p class="text-gray-500">Add a new location admin</p>
                </a>
            </div>
        </div>
        
        <!-- Locations List -->
        <div class="bg-white rounded-2xl shadow-md p-6 mb-8 border border-gray-100">
            <div class="flex justify-between items-center mb-6">
                <h2 class="text-2xl font-bold text-gray-800 flex items-center">
                    <span class="bg-red-100 text-red-600 p-2 rounded-lg mr-3">
                        <i class="fas fa-map-marker-alt"></i>
                    </span>
                    Locations
                </h2>
                <a href="create_location.php" class="bg-indigo-600 hover:bg-indigo-700 text-white px-5 py-2 rounded-xl transition flex items-center glow-on-hover">
                    <i class="fas fa-plus mr-2"></i> Add Location
                </a>
            </div>
            
            <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                <table class="min-w-full bg-white">
                    <thead class="bg-gray-50">
                        <tr>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Slug</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Reward Threshold</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Registration Link</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($locations as $location): ?>
                        <tr class="table-row-hover transition">
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($location['name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($location['slug']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo $location['reward_threshold']; ?></td>
                            <td class="py-4 px-6 border-b">
                                <?php
                                // Generate the registration link using the getJoinUrl function
                                $registrationLink = getJoinUrl($location['slug']);
                                ?>
                                <a href="<?php echo htmlspecialchars($registrationLink); ?>" 
                                   class="text-indigo-600 hover:text-indigo-800 flex items-center" target="_blank">
                                    <i class="fas fa-link mr-1"></i> Registration Link
                                </a>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <div class="flex space-x-3">
                                    <a href="edit_location.php?id=<?php echo $location['id']; ?>" 
                                       class="bg-blue-100 text-blue-600 px-3 py-1 rounded-lg hover:bg-blue-200 transition flex items-center">
                                        <i class="fas fa-edit mr-1"></i> Edit
                                    </a>
                                    <a href="view_location.php?id=<?php echo $location['id']; ?>" 
                                       class="bg-green-100 text-green-600 px-3 py-1 rounded-lg hover:bg-green-200 transition flex items-center">
                                        <i class="fas fa-eye mr-1"></i> View
                                    </a>
                                </div>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                        
                        <?php if (empty($locations)): ?>
                        <tr>
                            <td colspan="5" class="py-8 text-center text-gray-500">
                                <div class="flex flex-col items-center">
                                    <div class="bg-gray-100 p-4 rounded-full mb-3">
                                        <i class="fas fa-store-slash text-3xl text-gray-400"></i>
                                    </div>
                                    <p>No locations found</p>
                                </div>
                            </td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
        
        <!-- Recent Customers -->
        <div class="bg-white rounded-2xl shadow-md p-6 border border-gray-100">
            <div class="flex justify-between items-center mb-6">
                <h2 class="text-2xl font-bold text-gray-800 flex items-center">
                    <span class="bg-green-100 text-green-600 p-2 rounded-lg mr-3">
                        <i class="fas fa-users"></i>
                    </span>
                    Recent Customers
                </h2>
                <div class="flex items-center">
                    <form action="all_customers.php" method="GET" class="mr-4">
                        <select name="location_id" class="border border-gray-300 rounded-lg px-3 py-2 focus:outline-none focus:ring-2 focus:ring-indigo-500">
                            <option value="">All Locations</option>
                            <?php foreach ($locations as $location): ?>
                            <option value="<?php echo $location['id']; ?>"><?php echo htmlspecialchars($location['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                        <button type="submit" class="bg-indigo-100 text-indigo-600 px-3 py-2 rounded-lg hover:bg-indigo-200 transition ml-2">
                            <i class="fas fa-filter mr-1"></i> Filter
                        </button>
                    </form>
                    <a href="all_customers.php" class="text-indigo-600 hover:text-indigo-800 flex items-center px-4 py-2 rounded-lg hover:bg-indigo-50 transition">
                        <span>View All</span>
                        <i class="fas fa-arrow-right ml-2"></i>
                    </a>
                </div>
            </div>
            
            <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                <table class="min-w-full bg-white">
                    <thead class="bg-gray-50">
                        <tr>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Email</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Location</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Card Number</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Stamps</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php 
                        // Display only the 10 most recent customers
                        $recentCustomers = array_slice($customers, 0, 10);
                        foreach ($recentCustomers as $customer): 
                        ?>
                        <tr class="table-row-hover transition">
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['email']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['location_name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($customer['card_number'] ?? 'N/A'); ?></td>
                            <td class="py-4 px-6 border-b">
                                <div class="flex items-center">
                                    <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] > 0): ?>
                                    <div class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-full flex items-center">
                                        <span class="mr-1"><?php echo $customer['stamp_count'] ?? '0'; ?></span>
                                        <i class="fas fa-stamp text-xs"></i>
                                    </div>
                                    <?php else: ?>
                                    <span class="text-gray-500">0</span>
                                    <?php endif; ?>
                                    
                                    <?php if (isset($customer['stamp_count']) && $customer['stamp_count'] >= 10): ?>
                                    <span class="ml-2 bg-yellow-100 text-yellow-600 px-2 py-1 rounded-full text-xs flex items-center">
                                        <i class="fas fa-award mr-1"></i> Reward
                                    </span>
                                    <?php endif; ?>
                                </div>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <?php if (!empty($customer['card_number'])): ?>
                                    <a href="../../customer/card.php?card_number=<?php echo urlencode($customer['card_number']); ?>" 
                                   class="bg-indigo-100 text-indigo-600 px-3 py-1 rounded-lg hover:bg-indigo-200 transition flex items-center w-max" target="_blank">
                                    <i class="fas fa-id-card mr-1"></i> View Card
                                </a>
                                <?php endif; ?>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                        
                        <?php if (empty($recentCustomers)): ?>
                        <tr>
                            <td colspan="6" class="py-8 text-center text-gray-500">
                                <div class="flex flex-col items-center">
                                    <div class="bg-gray-100 p-4 rounded-full mb-3">
                                        <i class="fas fa-user-slash text-3xl text-gray-400"></i>
                                    </div>
                                    <p>No customers found</p>
                                </div>
                            </td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
        
        <!-- Location Admins -->
        <div class="bg-white rounded-2xl shadow-md p-6 mb-8 border border-gray-100">
            <div class="flex justify-between items-center mb-6">
                <h2 class="text-2xl font-bold text-gray-800 flex items-center">
                    <span class="bg-purple-100 text-purple-600 p-2 rounded-lg mr-3">
                        <i class="fas fa-user-shield"></i>
                    </span>
                    Location Administrators
                </h2>
                <a href="create_admin.php" class="bg-indigo-600 hover:bg-indigo-700 text-white px-5 py-2 rounded-xl transition flex items-center glow-on-hover">
                    <i class="fas fa-plus mr-2"></i> Add Admin
                </a>
            </div>
            
            <div class="overflow-x-auto table-container shadow-sm border border-gray-200">
                <table class="min-w-full bg-white">
                    <thead class="bg-gray-50">
                        <tr>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Name</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Username</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Email</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Location</th>
                            <th class="py-4 px-6 border-b text-left font-semibold text-gray-600">Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($locationAdmins as $admin): ?>
                        <tr class="table-row-hover transition">
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($admin['name']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($admin['username']); ?></td>
                            <td class="py-4 px-6 border-b"><?php echo htmlspecialchars($admin['email']); ?></td>
                            <td class="py-4 px-6 border-b">
                                <span class="bg-blue-100 text-blue-600 px-3 py-1 rounded-full text-sm">
                                    <?php echo htmlspecialchars($admin['location_name'] ?? 'No Location Assigned'); ?>
                                </span>
                            </td>
                            <td class="py-4 px-6 border-b">
                                <a href="reset_admin_password.php?id=<?php echo $admin['id']; ?>" 
                                   class="bg-yellow-100 text-yellow-600 px-3 py-1 rounded-lg hover:bg-yellow-200 transition flex items-center w-max">
                                    <i class="fas fa-key mr-1"></i> Reset Password
                                </a>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                        
                        <?php if (empty($locationAdmins)): ?>
                        <tr>
                            <td colspan="5" class="py-8 text-center text-gray-500">
                                <div class="flex flex-col items-center">
                                    <div class="bg-gray-100 p-4 rounded-full mb-3">
                                        <i class="fas fa-user-slash text-3xl text-gray-400"></i>
                                    </div>
                                    <p>No location administrators found</p>
                                </div>
                            </td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    
    <!-- Footer -->
    <footer class="bg-white py-6 border-t mt-8">
        <div class="container mx-auto px-6 text-center">
            <div class="flex justify-center space-x-6 mb-4">
                <a href="#" class="text-gray-400 hover:text-indigo-600 transition">
                    <i class="fab fa-facebook-f"></i>
                </a>
                <a href="#" class="text-gray-400 hover:text-indigo-600 transition">
                    <i class="fab fa-twitter"></i>
                </a>
                <a href="#" class="text-gray-400 hover:text-indigo-600 transition">
                    <i class="fab fa-instagram"></i>
                </a>
            </div>
            <p class="text-gray-500 text-sm">© <?php echo date('Y'); ?> Pointify. All rights reserved.</p>
        </div>
    </footer>
</body>
</html> 