<?php
require_once '../../includes/auth.php';
requireSuperAdmin();

$error = null;
$success = null;
$admin = null;

if (isset($_GET['id'])) {
    $adminId = $_GET['id'];
    
    // Get admin details
    $conn = getDbConnection();
    $stmt = $conn->prepare("
        SELECT u.*, l.name as location_name 
        FROM users u 
        LEFT JOIN locations l ON u.location_id = l.id 
        WHERE u.id = :id AND u.role = 'location_admin'
    ");
    $stmt->bindParam(':id', $adminId);
    $stmt->execute();
    $admin = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$admin) {
        header('Location: dashboard.php');
        exit;
    }
    
    if (isset($_POST['confirm_reset'])) {
        $newPassword = trim($_POST['new_password']);
        $confirmPassword = trim($_POST['confirm_password']);
        
        // Validate passwords
        if (empty($newPassword)) {
            $error = "Password cannot be empty";
        } elseif ($newPassword !== $confirmPassword) {
            $error = "Passwords do not match";
        } else {
            $result = resetAdminPassword($adminId, $newPassword);
            
            if ($result['success']) {
                $success = "Password has been successfully reset.";
            } else {
                $error = $result['message'];
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Admin Password - Pointify</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
</head>
<body class="bg-gray-50 min-h-screen">
    <div class="container mx-auto px-4 py-8">
        <div class="max-w-md mx-auto bg-white rounded-xl shadow-md overflow-hidden">
            <div class="p-8">
                <div class="flex items-center justify-center mb-6">
                    <span class="bg-yellow-100 text-yellow-600 p-3 rounded-full">
                        <i class="fas fa-key text-xl"></i>
                    </span>
                </div>
                
                <h2 class="text-2xl font-bold text-center mb-6">Reset Admin Password</h2>
                
                <?php if ($admin): ?>
                    <div class="mb-6">
                        <p class="text-gray-600 mb-2">Reset password for:</p>
                        <div class="bg-gray-50 p-4 rounded-lg">
                            <p class="font-semibold"><?php echo htmlspecialchars($admin['name']); ?></p>
                            <p class="text-gray-500"><?php echo htmlspecialchars($admin['email']); ?></p>
                            <p class="text-sm text-blue-600 mt-1">
                                <?php echo htmlspecialchars($admin['location_name'] ?? 'No Location Assigned'); ?>
                            </p>
                        </div>
                    </div>
                    
                    <?php if ($error): ?>
                        <div class="bg-red-100 text-red-600 p-4 rounded-lg mb-6">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                    <?php endif; ?>
                    
                    <?php if ($success): ?>
                        <div class="bg-green-100 text-green-600 p-4 rounded-lg mb-6">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="text-center">
                            <a href="dashboard.php" class="text-indigo-600 hover:text-indigo-800">
                                Return to Dashboard
                            </a>
                        </div>
                    <?php else: ?>
                        <form method="post" class="space-y-4">
                            <div>
                                <label for="new_password" class="block text-sm font-medium text-gray-700 mb-1">
                                    New Password
                                </label>
                                <input type="password" 
                                       id="new_password" 
                                       name="new_password" 
                                       class="w-full px-3 py-2 border border-gray-300 rounded-lg focus:outline-none focus:ring-2 focus:ring-indigo-500"
                                       required>
                            </div>
                            
                            <div>
                                <label for="confirm_password" class="block text-sm font-medium text-gray-700 mb-1">
                                    Confirm Password
                                </label>
                                <input type="password" 
                                       id="confirm_password" 
                                       name="confirm_password" 
                                       class="w-full px-3 py-2 border border-gray-300 rounded-lg focus:outline-none focus:ring-2 focus:ring-indigo-500"
                                       required>
                            </div>
                            
                            <div class="flex justify-end space-x-3 pt-4">
                                <a href="dashboard.php" 
                                   class="px-4 py-2 bg-gray-100 text-gray-600 rounded-lg hover:bg-gray-200 transition">
                                    Cancel
                                </a>
                                <button type="submit" 
                                        name="confirm_reset" 
                                        class="px-4 py-2 bg-yellow-500 text-white rounded-lg hover:bg-yellow-600 transition">
                                    Reset Password
                                </button>
                            </div>
                        </form>
                    <?php endif; ?>
                <?php else: ?>
                    <div class="text-center">
                        <p class="text-gray-600">Administrator not found.</p>
                        <a href="dashboard.php" class="text-indigo-600 hover:text-indigo-800 mt-4 inline-block">
                            Return to Dashboard
                        </a>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</body>
</html> 