<?php
require_once '../includes/functions.php';

// Check if card_number parameter is provided
if (!isset($_GET['card_number'])) {
    die("Card number parameter is required");
}

$cardNumber = $_GET['card_number'];

// Get card details
$conn = getDbConnection();
$stmt = $conn->prepare("
    SELECT lc.*, c.name, c.email, l.name as location_name, l.logo_url, l.reward_threshold, l.reward_description
    FROM loyalty_cards lc
    JOIN customers c ON lc.customer_id = c.id
    JOIN locations l ON c.location_id = l.id
    WHERE lc.card_number = :card_number
");
$stmt->bindParam(':card_number', $cardNumber);
$stmt->execute();
$card = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$card) {
    die("Invalid card number");
}

// Generate barcode data
$barcodeData = generatePDF417BarcodeData($cardNumber);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Loyalty Card - <?php echo htmlspecialchars($card['location_name']); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Arial', sans-serif;
        }
        .loyalty-card {
            background-color: white;
            border-radius: 16px;
            overflow: hidden;
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
            max-width: 400px;
            margin: 0 auto;
        }
        .card-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 16px;
            border-bottom: 1px solid #f0f0f0;
        }
        .logo-container {
            display: flex;
            align-items: center;
        }
        .logo {
            width: 48px;
            height: 48px;
            border-radius: 50%;
            margin-right: 12px;
        }
        .collected-stamps {
            color: #4361ee;
            font-size: 24px;
            font-weight: bold;
        }
        .promotion {
            background-color: #fff;
            padding: 16px;
            text-align: center;
            border-bottom: 1px solid #f0f0f0;
        }
        .promotion-text {
            color: #b91c1c;
            font-size: 20px;
            font-weight: bold;
            letter-spacing: 1px;
        }
        .coffee-cups {
            display: flex;
            justify-content: center;
            margin-top: 12px;
            gap: 8px;
        }
        .coffee-cup {
            width: 40px;
            height: 40px;
            position: relative;
        }
        .coffee-cup img {
            width: 100%;
            height: 100%;
            object-fit: contain;
        }
        .card-info {
            display: flex;
            justify-content: space-between;
            padding: 16px;
            color: #4361ee;
            border-bottom: 1px solid #f0f0f0;
        }
        .barcode-container {
            padding: 24px;
            display: flex;
            justify-content: center;
        }
        .barcode-container img {
            max-width: 100%;
            height: auto;
        }
        .add-to-wallet {
            display: block;
            background-color: #000;
            color: white;
            text-align: center;
            padding: 12px;
            margin: 16px auto;
            border-radius: 8px;
            text-decoration: none;
            width: 80%;
            max-width: 300px;
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen p-4">
    <div class="loyalty-card">
        <!-- Card Header with Logo and Collected Count -->
        <div class="card-header">
            <div class="logo-container">
                <img src="<?php echo htmlspecialchars($card['logo_url'] ?? '../assets/images/default-logo.png'); ?>" alt="Logo" class="logo">
                <div>
                    <h1 class="text-xl font-bold"><?php echo htmlspecialchars($card['location_name']); ?></h1>
                </div>
            </div>
            <div class="collected-stamps">
                COLLECTED<br>
                <span class="text-3xl"><?php echo htmlspecialchars($card['stamp_count']); ?></span>
            </div>
        </div>
        
        <!-- Promotion Section -->
        <div class="promotion">
            <div class="promotion-text">BUY <?php echo $card['reward_threshold'] - 1; ?> - GET 1 FREE!</div>
            <div class="coffee-cups">
                <?php 
                $totalCups = $card['reward_threshold']; // Use location's reward threshold instead of hardcoded 5
                $filledCups = min($card['stamp_count'], $card['reward_threshold']); // Filled cups based on stamps
                
                for ($i = 1; $i <= $totalCups; $i++): 
                    $isFilled = $i <= $filledCups;
                ?>
                    <div class="coffee-cup">
                        <img src="../assets/images/<?php echo $isFilled ? 'coffee-filled.png' : 'coffee-empty.png'; ?>" 
                             alt="<?php echo $isFilled ? 'Filled cup' : 'Empty cup'; ?>">
                    </div>
                <?php endfor; ?>
            </div>
        </div>
        
        <!-- Card Owner and Total -->
        <div class="card-info">
            <div>
                <div class="text-sm">CARD OWNER</div>
                <div class="text-lg font-semibold"><?php echo htmlspecialchars($card['name']); ?></div>
            </div>
            <div class="text-right">
                <div class="text-sm">OVERALL SUM</div>
                <div class="text-lg font-semibold">
                    <?php 
                    // Display total spent if available, otherwise show placeholder
                    echo isset($card['total_spent']) ? number_format($card['total_spent'], 2) : '0.00'; 
                    ?>
                </div>
            </div>
        </div>
        
        <!-- Barcode -->
        <div class="barcode-container">
            <img src="<?php echo $barcodeData; ?>" alt="Barcode" class="max-w-full">
        </div>
    </div>
    
    <!-- Add to Wallet Button -->
    <a href="generate_pkpass.php?card_number=<?php echo htmlspecialchars($cardNumber); ?>" class="add-to-wallet">
        Add to Apple Wallet
    </a>
</body>
</html> 