<?php
// Fix the path issue by using __DIR__ for absolute paths
require_once __DIR__ . '/config.php';
require_once __DIR__ . '/../includes/functions.php';

// Create database connection without selecting a database
try {
    $conn = new PDO(
        "mysql:host={$config['db']['host']}",
        $config['db']['username'],
        $config['db']['password']
    );
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    // Create database if it doesn't exist
    $conn->exec("CREATE DATABASE IF NOT EXISTS {$config['db']['database']}");
    
    // Select the database
    $conn->exec("USE {$config['db']['database']}");
    
    // Create locations table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS locations (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            slug VARCHAR(100) NOT NULL UNIQUE,
            registration_link VARCHAR(255) NOT NULL,
            reward_threshold INT DEFAULT 7,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
        )
    ");
    
    // Create customers table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS customers (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            email VARCHAR(100) NOT NULL UNIQUE,
            location_id INT NOT NULL,
            is_verified BOOLEAN DEFAULT FALSE,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (location_id) REFERENCES locations(id)
        )
    ");
    
    // Create loyalty_cards table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS loyalty_cards (
            id INT AUTO_INCREMENT PRIMARY KEY,
            customer_id INT NOT NULL,
            card_number VARCHAR(50) NOT NULL UNIQUE,
            stamp_count INT DEFAULT 0,
            rewards_earned INT DEFAULT 0,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (customer_id) REFERENCES customers(id)
        )
    ");
    
    // Create otp_verifications table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS otp_verifications (
            id INT AUTO_INCREMENT PRIMARY KEY,
            customer_id INT NOT NULL,
            otp VARCHAR(10) NOT NULL,
            expires_at DATETIME NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (customer_id) REFERENCES customers(id)
        )
    ");
    
    // Create users table for admins
    $conn->exec("
        CREATE TABLE IF NOT EXISTS users (
            id INT AUTO_INCREMENT PRIMARY KEY,
            username VARCHAR(50) NOT NULL UNIQUE,
            password VARCHAR(255) NOT NULL,
            name VARCHAR(100) NOT NULL,
            email VARCHAR(100) NOT NULL UNIQUE,
            role ENUM('super_admin', 'location_admin') NOT NULL,
            location_id INT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (location_id) REFERENCES locations(id)
        )
    ");
    
    // Insert demo data
    // Add a demo location
    $stmt = $conn->prepare("
        INSERT INTO locations (name, slug, registration_link, reward_threshold) 
        VALUES ('Cafe X', 'cafe-x', :registration_link, 7)
    ");
    $registrationLink = BASE_URL . 'customer/register.php?location=cafe-x';
    $stmt->bindParam(':registration_link', $registrationLink);
    $stmt->execute();
    
    // Add a super admin user
    $stmt = $conn->prepare("
        INSERT INTO users (username, password, name, email, role) 
        VALUES ('admin', :password, 'Super Admin', 'admin@example.com', 'super_admin')
    ");
    $hashedPassword = password_hash('admin123', PASSWORD_DEFAULT);
    $stmt->bindParam(':password', $hashedPassword);
    $stmt->execute();
    
    echo "Setup completed successfully!";
    
} catch(PDOException $e) {
    die("Setup failed: " . $e->getMessage());
}

// Connect to the database
$conn = getDbConnection();

// Create tables
try {
    // Locations table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS locations (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            slug VARCHAR(100) NOT NULL UNIQUE,
            registration_link VARCHAR(255) NOT NULL,
            reward_threshold INT NOT NULL DEFAULT 7,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
        )
    ");
    
    // Customers table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS customers (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            email VARCHAR(100) NOT NULL UNIQUE,
            location_id INT NOT NULL,
            is_verified BOOLEAN DEFAULT FALSE,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (location_id) REFERENCES locations(id)
        )
    ");
    
    // Loyalty cards table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS loyalty_cards (
            id INT AUTO_INCREMENT PRIMARY KEY,
            customer_id INT NOT NULL UNIQUE,
            card_number VARCHAR(20) NOT NULL UNIQUE,
            stamp_count INT NOT NULL DEFAULT 0,
            rewards_earned INT DEFAULT 0,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (customer_id) REFERENCES customers(id)
        )
    ");
    
    // OTP verifications table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS otp_verifications (
            id INT AUTO_INCREMENT PRIMARY KEY,
            customer_id INT NOT NULL,
            otp VARCHAR(10) NOT NULL,
            expires_at DATETIME NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (customer_id) REFERENCES customers(id)
        )
    ");
    
    // Users (admins) table
    $conn->exec("
        CREATE TABLE IF NOT EXISTS users (
            id INT AUTO_INCREMENT PRIMARY KEY,
            username VARCHAR(50) NOT NULL UNIQUE,
            password VARCHAR(255) NOT NULL,
            name VARCHAR(100) NOT NULL,
            email VARCHAR(100) NOT NULL UNIQUE,
            role ENUM('super_admin', 'location_admin') NOT NULL,
            location_id INT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (location_id) REFERENCES locations(id)
        )
    ");
    
    echo "Tables created successfully<br>";
    
    // Insert demo data
    
    // Check if we already have data
    $stmt = $conn->query("SELECT COUNT(*) FROM locations");
    $locationCount = $stmt->fetchColumn();
    
    if ($locationCount == 0) {
        // Insert demo locations
        $conn->exec("
            INSERT INTO locations (name, slug, registration_link, reward_threshold) VALUES
            ('Cafe X', 'cafe-x', '" . BASE_URL . "customer/register.php?location=cafe-x', 7),
            ('Coffee Shop', 'coffee-shop', '" . BASE_URL . "customer/register.php?location=coffee-shop', 10),
            ('Bakery', 'bakery', '" . BASE_URL . "customer/register.php?location=bakery', 8)
        ");
        
        // Insert super admin user
        $adminPassword = password_hash('admin123', PASSWORD_DEFAULT);
        $conn->exec("
            INSERT INTO users (username, password, name, email, role) VALUES
            ('admin', '$adminPassword', 'Super Admin', 'admin@example.com', 'super_admin')
        ");
        
        // Insert location admins
        $managerPassword = password_hash('manager123', PASSWORD_DEFAULT);
        $conn->exec("
            INSERT INTO users (username, password, name, email, role, location_id) VALUES
            ('cafe_manager', '$managerPassword', 'Cafe Manager', 'cafe@example.com', 'location_admin', 1),
            ('coffee_manager', '$managerPassword', 'Coffee Manager', 'coffee@example.com', 'location_admin', 2),
            ('bakery_manager', '$managerPassword', 'Bakery Manager', 'bakery@example.com', 'location_admin', 3)
        ");
        
        // Insert demo customers
        $conn->exec("
            INSERT INTO customers (name, email, location_id, is_verified) VALUES
            ('John Doe', 'john@example.com', 1, TRUE),
            ('Jane Smith', 'jane@example.com', 1, TRUE),
            ('Bob Johnson', 'bob@example.com', 2, TRUE),
            ('Alice Brown', 'alice@example.com', 2, TRUE),
            ('Charlie Davis', 'charlie@example.com', 3, TRUE)
        ");
        
        // Insert loyalty cards
        $conn->exec("
            INSERT INTO loyalty_cards (customer_id, card_number, stamp_count) VALUES
            (1, 'LC20230001', 3),
            (2, 'LC20230002', 5),
            (3, 'LC20230003', 2),
            (4, 'LC20230004', 8),
            (5, 'LC20230005', 4)
        ");
        
        echo "Demo data inserted successfully<br>";
    } else {
        echo "Demo data already exists<br>";
    }
    
    echo "Setup completed successfully!";
} catch(PDOException $e) {
    die("Setup failed: " . $e->getMessage());
}
?> 